
# Slot: object




URI: [biolink:macromolecular_machine_to_molecular_activity_association_object](https://w3id.org/biolink/vocab/macromolecular_machine_to_molecular_activity_association_object)

## Domain and Range

[MacromolecularMachineToMolecularActivityAssociation](MacromolecularMachineToMolecularActivityAssociation.md) ->  <sub>REQ</sub> [MolecularActivity](MolecularActivity.md)

## Parents

 *  is_a: [object](functional_association_object.md)

## Children


## Used by

 * [MacromolecularMachineToMolecularActivityAssociation](MacromolecularMachineToMolecularActivityAssociation.md)
